# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKLabelMapPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkBinaryImageToStatisticsLabelMapFilterPython
else:
    import _itkBinaryImageToStatisticsLabelMapFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImagePython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkMatrixPython
import itk.vnl_matrixPython
import itk.vnl_vectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.itkPointPython
import itk.itkIndexPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkRGBAPixelPython
import itk.itkImageRegionPython
import itk.ITKCommonBasePython
import itk.itkRGBPixelPython
import itk.ITKLabelMapBasePython
import itk.itkStatisticsLabelObjectPython
import itk.itkHistogramPython
import itk.itkSamplePython
import itk.itkArrayPython
import itk.itkAffineTransformPython
import itk.itkTransformBasePython
import itk.itkDiffusionTensor3DPython
import itk.itkOptimizerParametersPython
import itk.itkArray2DPython
import itk.itkVariableLengthVectorPython
import itk.itkMatrixOffsetTransformBasePython
import itk.itkShapeLabelObjectPython
import itk.itkLabelObjectPython
import itk.itkLabelObjectLinePython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkVectorImagePython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterCommonPython

def itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_New():
    return itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2.New()

class itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2(itk.ITKLabelMapBasePython.itkImageToImageFilterIUC2LM2):
    r"""Proxy of C++ itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_Pointer"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_Pointer"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_Clone(self)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_FullyConnectedOff(self)
    InputEqualityComparableCheck = _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_InputOStreamWritableCheck
    

    def SetOutputBackgroundValue(self, _arg):
        r"""
        SetOutputBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_SetOutputBackgroundValue(self, _arg)

    def GetOutputBackgroundValue(self):
        r"""GetOutputBackgroundValue(self) -> unsigned long"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_GetOutputBackgroundValue(self)

    def SetInputForegroundValue(self, _arg):
        r"""
        SetInputForegroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_SetInputForegroundValue(self, _arg)

    def GetInputForegroundValue(self):
        r"""GetInputForegroundValue(self) -> unsigned char"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_GetInputForegroundValue(self)

    def SetComputeFeretDiameter(self, _arg):
        r"""
        SetComputeFeretDiameter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_SetComputeFeretDiameter(self, _arg)

    def GetComputeFeretDiameter(self):
        r"""GetComputeFeretDiameter(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_GetComputeFeretDiameter(self)

    def ComputeFeretDiameterOn(self):
        r"""ComputeFeretDiameterOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_ComputeFeretDiameterOn(self)

    def ComputeFeretDiameterOff(self):
        r"""ComputeFeretDiameterOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_ComputeFeretDiameterOff(self)

    def SetComputePerimeter(self, _arg):
        r"""
        SetComputePerimeter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_SetComputePerimeter(self, _arg)

    def GetComputePerimeter(self):
        r"""GetComputePerimeter(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_GetComputePerimeter(self)

    def ComputePerimeterOn(self):
        r"""ComputePerimeterOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_ComputePerimeterOn(self)

    def ComputePerimeterOff(self):
        r"""ComputePerimeterOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_ComputePerimeterOff(self)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageF2 const *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageF2"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageF2 const *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_SetInput2(self, input)

    def SetComputeHistogram(self, _arg):
        r"""
        SetComputeHistogram(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_SetComputeHistogram(self, _arg)

    def GetComputeHistogram(self):
        r"""GetComputeHistogram(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_GetComputeHistogram(self)

    def ComputeHistogramOn(self):
        r"""ComputeHistogramOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_ComputeHistogramOn(self)

    def ComputeHistogramOff(self):
        r"""ComputeHistogramOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_ComputeHistogramOff(self)

    def SetNumberOfBins(self, _arg):
        r"""
        SetNumberOfBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_SetNumberOfBins(self, _arg)

    def GetNumberOfBins(self):
        r"""GetNumberOfBins(self) -> unsigned int const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_GetNumberOfBins(self)
    __swig_destroy__ = _itkBinaryImageToStatisticsLabelMapFilterPython.delete_itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2

        Create a new object of the class itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2 in _itkBinaryImageToStatisticsLabelMapFilterPython:
_itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2_swigregister(itkBinaryImageToStatisticsLabelMapFilterIUC2IF2LM2)

def itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_New():
    return itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2.New()

class itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2(itk.ITKLabelMapBasePython.itkImageToImageFilterIUC2LM2):
    r"""Proxy of C++ itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_Pointer"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_Pointer"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_Clone(self)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_FullyConnectedOff(self)
    InputEqualityComparableCheck = _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_InputOStreamWritableCheck
    

    def SetOutputBackgroundValue(self, _arg):
        r"""
        SetOutputBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_SetOutputBackgroundValue(self, _arg)

    def GetOutputBackgroundValue(self):
        r"""GetOutputBackgroundValue(self) -> unsigned long"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_GetOutputBackgroundValue(self)

    def SetInputForegroundValue(self, _arg):
        r"""
        SetInputForegroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_SetInputForegroundValue(self, _arg)

    def GetInputForegroundValue(self):
        r"""GetInputForegroundValue(self) -> unsigned char"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_GetInputForegroundValue(self)

    def SetComputeFeretDiameter(self, _arg):
        r"""
        SetComputeFeretDiameter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_SetComputeFeretDiameter(self, _arg)

    def GetComputeFeretDiameter(self):
        r"""GetComputeFeretDiameter(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_GetComputeFeretDiameter(self)

    def ComputeFeretDiameterOn(self):
        r"""ComputeFeretDiameterOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_ComputeFeretDiameterOn(self)

    def ComputeFeretDiameterOff(self):
        r"""ComputeFeretDiameterOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_ComputeFeretDiameterOff(self)

    def SetComputePerimeter(self, _arg):
        r"""
        SetComputePerimeter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_SetComputePerimeter(self, _arg)

    def GetComputePerimeter(self):
        r"""GetComputePerimeter(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_GetComputePerimeter(self)

    def ComputePerimeterOn(self):
        r"""ComputePerimeterOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_ComputePerimeterOn(self)

    def ComputePerimeterOff(self):
        r"""ComputePerimeterOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_ComputePerimeterOff(self)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageSS2"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_SetInput2(self, input)

    def SetComputeHistogram(self, _arg):
        r"""
        SetComputeHistogram(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_SetComputeHistogram(self, _arg)

    def GetComputeHistogram(self):
        r"""GetComputeHistogram(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_GetComputeHistogram(self)

    def ComputeHistogramOn(self):
        r"""ComputeHistogramOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_ComputeHistogramOn(self)

    def ComputeHistogramOff(self):
        r"""ComputeHistogramOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_ComputeHistogramOff(self)

    def SetNumberOfBins(self, _arg):
        r"""
        SetNumberOfBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_SetNumberOfBins(self, _arg)

    def GetNumberOfBins(self):
        r"""GetNumberOfBins(self) -> unsigned int const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_GetNumberOfBins(self)
    __swig_destroy__ = _itkBinaryImageToStatisticsLabelMapFilterPython.delete_itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2

        Create a new object of the class itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2 in _itkBinaryImageToStatisticsLabelMapFilterPython:
_itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2_swigregister(itkBinaryImageToStatisticsLabelMapFilterIUC2ISS2LM2)

def itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_New():
    return itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2.New()

class itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2(itk.ITKLabelMapBasePython.itkImageToImageFilterIUC2LM2):
    r"""Proxy of C++ itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_Pointer"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_Pointer"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_Clone(self)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_FullyConnectedOff(self)
    InputEqualityComparableCheck = _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_InputOStreamWritableCheck
    

    def SetOutputBackgroundValue(self, _arg):
        r"""
        SetOutputBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_SetOutputBackgroundValue(self, _arg)

    def GetOutputBackgroundValue(self):
        r"""GetOutputBackgroundValue(self) -> unsigned long"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_GetOutputBackgroundValue(self)

    def SetInputForegroundValue(self, _arg):
        r"""
        SetInputForegroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_SetInputForegroundValue(self, _arg)

    def GetInputForegroundValue(self):
        r"""GetInputForegroundValue(self) -> unsigned char"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_GetInputForegroundValue(self)

    def SetComputeFeretDiameter(self, _arg):
        r"""
        SetComputeFeretDiameter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_SetComputeFeretDiameter(self, _arg)

    def GetComputeFeretDiameter(self):
        r"""GetComputeFeretDiameter(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_GetComputeFeretDiameter(self)

    def ComputeFeretDiameterOn(self):
        r"""ComputeFeretDiameterOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_ComputeFeretDiameterOn(self)

    def ComputeFeretDiameterOff(self):
        r"""ComputeFeretDiameterOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_ComputeFeretDiameterOff(self)

    def SetComputePerimeter(self, _arg):
        r"""
        SetComputePerimeter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_SetComputePerimeter(self, _arg)

    def GetComputePerimeter(self):
        r"""GetComputePerimeter(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_GetComputePerimeter(self)

    def ComputePerimeterOn(self):
        r"""ComputePerimeterOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_ComputePerimeterOn(self)

    def ComputePerimeterOff(self):
        r"""ComputePerimeterOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_ComputePerimeterOff(self)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageUC2"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_SetInput2(self, input)

    def SetComputeHistogram(self, _arg):
        r"""
        SetComputeHistogram(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_SetComputeHistogram(self, _arg)

    def GetComputeHistogram(self):
        r"""GetComputeHistogram(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_GetComputeHistogram(self)

    def ComputeHistogramOn(self):
        r"""ComputeHistogramOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_ComputeHistogramOn(self)

    def ComputeHistogramOff(self):
        r"""ComputeHistogramOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_ComputeHistogramOff(self)

    def SetNumberOfBins(self, _arg):
        r"""
        SetNumberOfBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_SetNumberOfBins(self, _arg)

    def GetNumberOfBins(self):
        r"""GetNumberOfBins(self) -> unsigned int const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_GetNumberOfBins(self)
    __swig_destroy__ = _itkBinaryImageToStatisticsLabelMapFilterPython.delete_itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2

        Create a new object of the class itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2 in _itkBinaryImageToStatisticsLabelMapFilterPython:
_itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2_swigregister(itkBinaryImageToStatisticsLabelMapFilterIUC2IUC2LM2)

def itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_New():
    return itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3.New()

class itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3(itk.ITKLabelMapBasePython.itkImageToImageFilterIUC3LM3):
    r"""Proxy of C++ itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_Pointer"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_Pointer"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_Clone(self)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_FullyConnectedOff(self)
    InputEqualityComparableCheck = _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_InputOStreamWritableCheck
    

    def SetOutputBackgroundValue(self, _arg):
        r"""
        SetOutputBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_SetOutputBackgroundValue(self, _arg)

    def GetOutputBackgroundValue(self):
        r"""GetOutputBackgroundValue(self) -> unsigned long"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_GetOutputBackgroundValue(self)

    def SetInputForegroundValue(self, _arg):
        r"""
        SetInputForegroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_SetInputForegroundValue(self, _arg)

    def GetInputForegroundValue(self):
        r"""GetInputForegroundValue(self) -> unsigned char"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_GetInputForegroundValue(self)

    def SetComputeFeretDiameter(self, _arg):
        r"""
        SetComputeFeretDiameter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_SetComputeFeretDiameter(self, _arg)

    def GetComputeFeretDiameter(self):
        r"""GetComputeFeretDiameter(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_GetComputeFeretDiameter(self)

    def ComputeFeretDiameterOn(self):
        r"""ComputeFeretDiameterOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_ComputeFeretDiameterOn(self)

    def ComputeFeretDiameterOff(self):
        r"""ComputeFeretDiameterOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_ComputeFeretDiameterOff(self)

    def SetComputePerimeter(self, _arg):
        r"""
        SetComputePerimeter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_SetComputePerimeter(self, _arg)

    def GetComputePerimeter(self):
        r"""GetComputePerimeter(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_GetComputePerimeter(self)

    def ComputePerimeterOn(self):
        r"""ComputePerimeterOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_ComputePerimeterOn(self)

    def ComputePerimeterOff(self):
        r"""ComputePerimeterOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_ComputePerimeterOff(self)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageF3 const *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageF3"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageF3 const *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_SetInput2(self, input)

    def SetComputeHistogram(self, _arg):
        r"""
        SetComputeHistogram(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_SetComputeHistogram(self, _arg)

    def GetComputeHistogram(self):
        r"""GetComputeHistogram(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_GetComputeHistogram(self)

    def ComputeHistogramOn(self):
        r"""ComputeHistogramOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_ComputeHistogramOn(self)

    def ComputeHistogramOff(self):
        r"""ComputeHistogramOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_ComputeHistogramOff(self)

    def SetNumberOfBins(self, _arg):
        r"""
        SetNumberOfBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_SetNumberOfBins(self, _arg)

    def GetNumberOfBins(self):
        r"""GetNumberOfBins(self) -> unsigned int const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_GetNumberOfBins(self)
    __swig_destroy__ = _itkBinaryImageToStatisticsLabelMapFilterPython.delete_itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3

        Create a new object of the class itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3 in _itkBinaryImageToStatisticsLabelMapFilterPython:
_itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3_swigregister(itkBinaryImageToStatisticsLabelMapFilterIUC3IF3LM3)

def itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_New():
    return itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3.New()

class itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3(itk.ITKLabelMapBasePython.itkImageToImageFilterIUC3LM3):
    r"""Proxy of C++ itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_Pointer"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_Pointer"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_Clone(self)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_FullyConnectedOff(self)
    InputEqualityComparableCheck = _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_InputOStreamWritableCheck
    

    def SetOutputBackgroundValue(self, _arg):
        r"""
        SetOutputBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_SetOutputBackgroundValue(self, _arg)

    def GetOutputBackgroundValue(self):
        r"""GetOutputBackgroundValue(self) -> unsigned long"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_GetOutputBackgroundValue(self)

    def SetInputForegroundValue(self, _arg):
        r"""
        SetInputForegroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_SetInputForegroundValue(self, _arg)

    def GetInputForegroundValue(self):
        r"""GetInputForegroundValue(self) -> unsigned char"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_GetInputForegroundValue(self)

    def SetComputeFeretDiameter(self, _arg):
        r"""
        SetComputeFeretDiameter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_SetComputeFeretDiameter(self, _arg)

    def GetComputeFeretDiameter(self):
        r"""GetComputeFeretDiameter(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_GetComputeFeretDiameter(self)

    def ComputeFeretDiameterOn(self):
        r"""ComputeFeretDiameterOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_ComputeFeretDiameterOn(self)

    def ComputeFeretDiameterOff(self):
        r"""ComputeFeretDiameterOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_ComputeFeretDiameterOff(self)

    def SetComputePerimeter(self, _arg):
        r"""
        SetComputePerimeter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_SetComputePerimeter(self, _arg)

    def GetComputePerimeter(self):
        r"""GetComputePerimeter(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_GetComputePerimeter(self)

    def ComputePerimeterOn(self):
        r"""ComputePerimeterOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_ComputePerimeterOn(self)

    def ComputePerimeterOff(self):
        r"""ComputePerimeterOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_ComputePerimeterOff(self)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageSS3"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_SetInput2(self, input)

    def SetComputeHistogram(self, _arg):
        r"""
        SetComputeHistogram(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_SetComputeHistogram(self, _arg)

    def GetComputeHistogram(self):
        r"""GetComputeHistogram(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_GetComputeHistogram(self)

    def ComputeHistogramOn(self):
        r"""ComputeHistogramOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_ComputeHistogramOn(self)

    def ComputeHistogramOff(self):
        r"""ComputeHistogramOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_ComputeHistogramOff(self)

    def SetNumberOfBins(self, _arg):
        r"""
        SetNumberOfBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_SetNumberOfBins(self, _arg)

    def GetNumberOfBins(self):
        r"""GetNumberOfBins(self) -> unsigned int const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_GetNumberOfBins(self)
    __swig_destroy__ = _itkBinaryImageToStatisticsLabelMapFilterPython.delete_itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3

        Create a new object of the class itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3 in _itkBinaryImageToStatisticsLabelMapFilterPython:
_itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3_swigregister(itkBinaryImageToStatisticsLabelMapFilterIUC3ISS3LM3)

def itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_New():
    return itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3.New()

class itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3(itk.ITKLabelMapBasePython.itkImageToImageFilterIUC3LM3):
    r"""Proxy of C++ itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_Pointer"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_Pointer"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_Clone(self)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_FullyConnectedOff(self)
    InputEqualityComparableCheck = _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_InputOStreamWritableCheck
    

    def SetOutputBackgroundValue(self, _arg):
        r"""
        SetOutputBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_SetOutputBackgroundValue(self, _arg)

    def GetOutputBackgroundValue(self):
        r"""GetOutputBackgroundValue(self) -> unsigned long"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_GetOutputBackgroundValue(self)

    def SetInputForegroundValue(self, _arg):
        r"""
        SetInputForegroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_SetInputForegroundValue(self, _arg)

    def GetInputForegroundValue(self):
        r"""GetInputForegroundValue(self) -> unsigned char"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_GetInputForegroundValue(self)

    def SetComputeFeretDiameter(self, _arg):
        r"""
        SetComputeFeretDiameter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_SetComputeFeretDiameter(self, _arg)

    def GetComputeFeretDiameter(self):
        r"""GetComputeFeretDiameter(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_GetComputeFeretDiameter(self)

    def ComputeFeretDiameterOn(self):
        r"""ComputeFeretDiameterOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_ComputeFeretDiameterOn(self)

    def ComputeFeretDiameterOff(self):
        r"""ComputeFeretDiameterOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_ComputeFeretDiameterOff(self)

    def SetComputePerimeter(self, _arg):
        r"""
        SetComputePerimeter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_SetComputePerimeter(self, _arg)

    def GetComputePerimeter(self):
        r"""GetComputePerimeter(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_GetComputePerimeter(self)

    def ComputePerimeterOn(self):
        r"""ComputePerimeterOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_ComputePerimeterOn(self)

    def ComputePerimeterOff(self):
        r"""ComputePerimeterOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_ComputePerimeterOff(self)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageUC3"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_SetInput2(self, input)

    def SetComputeHistogram(self, _arg):
        r"""
        SetComputeHistogram(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_SetComputeHistogram(self, _arg)

    def GetComputeHistogram(self):
        r"""GetComputeHistogram(self) -> bool const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_GetComputeHistogram(self)

    def ComputeHistogramOn(self):
        r"""ComputeHistogramOn(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_ComputeHistogramOn(self)

    def ComputeHistogramOff(self):
        r"""ComputeHistogramOff(self)"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_ComputeHistogramOff(self)

    def SetNumberOfBins(self, _arg):
        r"""
        SetNumberOfBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_SetNumberOfBins(self, _arg)

    def GetNumberOfBins(self):
        r"""GetNumberOfBins(self) -> unsigned int const &"""
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_GetNumberOfBins(self)
    __swig_destroy__ = _itkBinaryImageToStatisticsLabelMapFilterPython.delete_itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3

        Create a new object of the class itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3 in _itkBinaryImageToStatisticsLabelMapFilterPython:
_itkBinaryImageToStatisticsLabelMapFilterPython.itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3_swigregister(itkBinaryImageToStatisticsLabelMapFilterIUC3IUC3LM3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def binary_image_to_statistics_label_map_filter(*args: itkt.ImageLike,  fully_connected: bool=..., output_background_value: int=..., input_foreground_value: int=..., compute_feret_diameter: bool=..., compute_perimeter: bool=..., feature_image: itkt.Image=..., compute_histogram: bool=..., number_of_bins: int=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for BinaryImageToStatisticsLabelMapFilter"""
    import itk

    kwarg_typehints = { 'fully_connected':fully_connected,'output_background_value':output_background_value,'input_foreground_value':input_foreground_value,'compute_feret_diameter':compute_feret_diameter,'compute_perimeter':compute_perimeter,'feature_image':feature_image,'compute_histogram':compute_histogram,'number_of_bins':number_of_bins }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.BinaryImageToStatisticsLabelMapFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def binary_image_to_statistics_label_map_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKLabelMap.BinaryImageToStatisticsLabelMapFilter
    binary_image_to_statistics_label_map_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    binary_image_to_statistics_label_map_filter.__doc__ = filter_object.__doc__



